# yousign_client

YousignClient - the Ruby gem for the Yousign API Swagger

For your information, the Yousign API documentation is available at https://dev.yousign.com/

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.1
- Package version: 1.0.3
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build yousign_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./yousign_client-1.0.3.gem
```
(for development, run `gem install --dev ./yousign_client-1.0.3.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'yousign_client', '~> 1.0.3'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/cashbee-team/yousign_client, then add the following in the Gemfile:

    gem 'yousign_client', :git => 'https://github.com/cashbee-team/yousign_client.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'yousign_client'

# Setup authorization
YousignClient.configure do |config|
  # Configure API key authorization: api_key
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = YousignClient::AuthenticationsApi.new

id = 'id_example' # String | 


begin
  #Find an Authentication by ID
  result = api_instance.authentications_email_id_get(id, )
  p result
rescue YousignClient::ApiError => e
  puts "Exception when calling AuthenticationsApi->authentications_email_id_get: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.yousign.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*YousignClient::AuthenticationsApi* | [**authentications_email_id_get**](docs/AuthenticationsApi.md#authentications_email_id_get) | **GET** /authentications/email/{id} | Find an Authentication by ID
*YousignClient::AuthenticationsApi* | [**authentications_email_id_put**](docs/AuthenticationsApi.md#authentications_email_id_put) | **PUT** /authentications/email/{id} | Update an Email Authentication
*YousignClient::AuthenticationsApi* | [**authentications_inwebo_id_get**](docs/AuthenticationsApi.md#authentications_inwebo_id_get) | **GET** /authentications/inwebo/{id} | Get an Authentication
*YousignClient::AuthenticationsApi* | [**authentications_inwebo_id_put**](docs/AuthenticationsApi.md#authentications_inwebo_id_put) | **PUT** /authentications/inwebo/{id} | Update an inwebo Authentication
*YousignClient::AuthenticationsApi* | [**authentications_sms_id_get**](docs/AuthenticationsApi.md#authentications_sms_id_get) | **GET** /authentications/sms/{id} | Find an Authentication by ID
*YousignClient::AuthenticationsApi* | [**authentications_sms_id_put**](docs/AuthenticationsApi.md#authentications_sms_id_put) | **PUT** /authentications/sms/{id} | Update an SMS Authentication
*YousignClient::CheckDocumentsApi* | [**check_document_bank_accounts_id_get**](docs/CheckDocumentsApi.md#check_document_bank_accounts_id_get) | **GET** /check-document/bank_accounts/{id} | Get informations about a bank document (RIB)
*YousignClient::CheckDocumentsApi* | [**check_document_bank_accounts_post**](docs/CheckDocumentsApi.md#check_document_bank_accounts_post) | **POST** /check-document/bank_accounts | Verify a bank document (RIB)
*YousignClient::CheckDocumentsApi* | [**check_document_identities_id_get**](docs/CheckDocumentsApi.md#check_document_identities_id_get) | **GET** /check-document/identities/{id} | Get informations about an identity document (passport, id cards)
*YousignClient::CheckDocumentsApi* | [**check_document_identities_post**](docs/CheckDocumentsApi.md#check_document_identities_post) | **POST** /check-document/identities | Verify an identity document (passport, id cards)
*YousignClient::ConsentProcessesApi* | [**consent_process_values_get**](docs/ConsentProcessesApi.md#consent_process_values_get) | **GET** /consent_process_values | Get list of Consent Process Value
*YousignClient::ConsentProcessesApi* | [**consent_process_values_id_get**](docs/ConsentProcessesApi.md#consent_process_values_id_get) | **GET** /consent_process_values/{id} | Get a Consent Process Value
*YousignClient::ConsentProcessesApi* | [**consent_process_values_post**](docs/ConsentProcessesApi.md#consent_process_values_post) | **POST** /consent_process_values | Create a new Consent Process Value
*YousignClient::ConsentProcessesApi* | [**consent_processes_get**](docs/ConsentProcessesApi.md#consent_processes_get) | **GET** /consent_processes | Get list of Consent Processes
*YousignClient::ConsentProcessesApi* | [**consent_processes_id_delete**](docs/ConsentProcessesApi.md#consent_processes_id_delete) | **DELETE** /consent_processes/{id} | Delete a Consent Process
*YousignClient::ConsentProcessesApi* | [**consent_processes_id_get**](docs/ConsentProcessesApi.md#consent_processes_id_get) | **GET** /consent_processes/{id} | Get a Consent Process
*YousignClient::ConsentProcessesApi* | [**consent_processes_id_put**](docs/ConsentProcessesApi.md#consent_processes_id_put) | **PUT** /consent_processes/{id} | Update a Consent Process
*YousignClient::ConsentProcessesApi* | [**consent_processes_post**](docs/ConsentProcessesApi.md#consent_processes_post) | **POST** /consent_processes | Create a new Consent Process
*YousignClient::FileObjectsApi* | [**file_objects_id_delete**](docs/FileObjectsApi.md#file_objects_id_delete) | **DELETE** /file_objects/{id} | Delete a File Object
*YousignClient::FileObjectsApi* | [**file_objects_id_get**](docs/FileObjectsApi.md#file_objects_id_get) | **GET** /file_objects/{id} | Find a File Object by ID
*YousignClient::FileObjectsApi* | [**file_objects_id_put**](docs/FileObjectsApi.md#file_objects_id_put) | **PUT** /file_objects/{id} | Update a File Object
*YousignClient::FileObjectsApi* | [**file_objects_post**](docs/FileObjectsApi.md#file_objects_post) | **POST** /file_objects | Create a new File Object
*YousignClient::FilesApi* | [**files_id_download_get**](docs/FilesApi.md#files_id_download_get) | **GET** /files/{id}/download | Download a File
*YousignClient::FilesApi* | [**files_id_duplicate_post**](docs/FilesApi.md#files_id_duplicate_post) | **POST** /files/{id}/duplicate | Duplicate a File
*YousignClient::FilesApi* | [**files_id_get**](docs/FilesApi.md#files_id_get) | **GET** /files/{id} | Find a File by ID
*YousignClient::FilesApi* | [**files_post**](docs/FilesApi.md#files_post) | **POST** /files | Create a new File
*YousignClient::MembersApi* | [**members_get**](docs/MembersApi.md#members_get) | **GET** /members | Get all Members
*YousignClient::MembersApi* | [**members_id_delete**](docs/MembersApi.md#members_id_delete) | **DELETE** /members/{id} | Delete a Member
*YousignClient::MembersApi* | [**members_id_proof_get**](docs/MembersApi.md#members_id_proof_get) | **GET** /members/{id}/proof | Get a proof file of a Member
*YousignClient::MembersApi* | [**members_id_put**](docs/MembersApi.md#members_id_put) | **PUT** /members/{id} | Edit a Member
*YousignClient::MembersApi* | [**members_post**](docs/MembersApi.md#members_post) | **POST** /members | Create a new Member
*YousignClient::OperationsApi* | [**operations_id_get**](docs/OperationsApi.md#operations_id_get) | **GET** /operations/{id} | Find an Operation by ID
*YousignClient::OperationsApi* | [**operations_post**](docs/OperationsApi.md#operations_post) | **POST** /operations | Create a new Operation
*YousignClient::OrganizationsApi* | [**organizations_get**](docs/OrganizationsApi.md#organizations_get) | **GET** /organizations | List all Organizations
*YousignClient::ProceduresApi* | [**export_procedures_get**](docs/ProceduresApi.md#export_procedures_get) | **GET** /export/procedures | Export Procedure list
*YousignClient::ProceduresApi* | [**procedures_get**](docs/ProceduresApi.md#procedures_get) | **GET** /procedures | Get Procedure list
*YousignClient::ProceduresApi* | [**procedures_id_delete**](docs/ProceduresApi.md#procedures_id_delete) | **DELETE** /procedures/{id} | Delete a Procedure
*YousignClient::ProceduresApi* | [**procedures_id_duplicate_post**](docs/ProceduresApi.md#procedures_id_duplicate_post) | **POST** /procedures/{id}/duplicate | Duplicate a Procedure
*YousignClient::ProceduresApi* | [**procedures_id_get**](docs/ProceduresApi.md#procedures_id_get) | **GET** /procedures/{id} | Find a Procedure by ID
*YousignClient::ProceduresApi* | [**procedures_id_proof_get**](docs/ProceduresApi.md#procedures_id_proof_get) | **GET** /procedures/{id}/proof | Get a Procedure proof file
*YousignClient::ProceduresApi* | [**procedures_id_put**](docs/ProceduresApi.md#procedures_id_put) | **PUT** /procedures/{id} | Update a Procedure
*YousignClient::ProceduresApi* | [**procedures_id_remind_post**](docs/ProceduresApi.md#procedures_id_remind_post) | **POST** /procedures/{id}/remind | Remind a Procedure
*YousignClient::ProceduresApi* | [**procedures_post**](docs/ProceduresApi.md#procedures_post) | **POST** /procedures | Create a new Procedure
*YousignClient::ServerStampsApi* | [**server_stamps_id_get**](docs/ServerStampsApi.md#server_stamps_id_get) | **GET** /server_stamps/{id} | Find a Server Stamp by ID
*YousignClient::ServerStampsApi* | [**server_stamps_post**](docs/ServerStampsApi.md#server_stamps_post) | **POST** /server_stamps | Create a Server Stamp
*YousignClient::SignatureUIsApi* | [**signature_ui_labels_get**](docs/SignatureUIsApi.md#signature_ui_labels_get) | **GET** /signature_ui_labels | Get Signature UI Labels
*YousignClient::SignatureUIsApi* | [**signature_ui_labels_id_delete**](docs/SignatureUIsApi.md#signature_ui_labels_id_delete) | **DELETE** /signature_ui_labels/{id} | Delete a Signature UI Label
*YousignClient::SignatureUIsApi* | [**signature_ui_labels_id_get**](docs/SignatureUIsApi.md#signature_ui_labels_id_get) | **GET** /signature_ui_labels/{id} | Find a Signature UI Label by ID
*YousignClient::SignatureUIsApi* | [**signature_ui_labels_id_put**](docs/SignatureUIsApi.md#signature_ui_labels_id_put) | **PUT** /signature_ui_labels/{id} | Update a Signature UI Label
*YousignClient::SignatureUIsApi* | [**signature_ui_labels_post**](docs/SignatureUIsApi.md#signature_ui_labels_post) | **POST** /signature_ui_labels | Create a new Signature UI Label
*YousignClient::SignatureUIsApi* | [**signature_uis_get**](docs/SignatureUIsApi.md#signature_uis_get) | **GET** /signature_uis | Get Signature UI list
*YousignClient::SignatureUIsApi* | [**signature_uis_id_delete**](docs/SignatureUIsApi.md#signature_uis_id_delete) | **DELETE** /signature_uis/{id} | Delete a Signature UI
*YousignClient::SignatureUIsApi* | [**signature_uis_id_get**](docs/SignatureUIsApi.md#signature_uis_id_get) | **GET** /signature_uis/{id} | Find a Signature UI by ID
*YousignClient::SignatureUIsApi* | [**signature_uis_id_put**](docs/SignatureUIsApi.md#signature_uis_id_put) | **PUT** /signature_uis/{id} | Update a Signature UI
*YousignClient::SignatureUIsApi* | [**signature_uis_post**](docs/SignatureUIsApi.md#signature_uis_post) | **POST** /signature_uis | Create a new Signature UI
*YousignClient::UserGroupsApi* | [**user_groups_get**](docs/UserGroupsApi.md#user_groups_get) | **GET** /user_groups | Get User Group list
*YousignClient::UserGroupsApi* | [**user_groups_id_get**](docs/UserGroupsApi.md#user_groups_id_get) | **GET** /user_groups/{id} | Find a User Group by ID
*YousignClient::UsersApi* | [**users_get**](docs/UsersApi.md#users_get) | **GET** /users | List all Users
*YousignClient::UsersApi* | [**users_id_delete**](docs/UsersApi.md#users_id_delete) | **DELETE** /users/{id} | Delete a User
*YousignClient::UsersApi* | [**users_id_get**](docs/UsersApi.md#users_id_get) | **GET** /users/{id} | Find a User by ID
*YousignClient::UsersApi* | [**users_id_put**](docs/UsersApi.md#users_id_put) | **PUT** /users/{id} | Update a User
*YousignClient::UsersApi* | [**users_post**](docs/UsersApi.md#users_post) | **POST** /users | Create a new User on Yousign application
*YousignClient::WorkspacesApi* | [**workspaces_get**](docs/WorkspacesApi.md#workspaces_get) | **GET** /workspaces | List all Workspaces


## Documentation for Models

 - [YousignClient::AuthenticationEmailOutput](docs/AuthenticationEmailOutput.md)
 - [YousignClient::AuthenticationInweboOutput](docs/AuthenticationInweboOutput.md)
 - [YousignClient::AuthenticationSmsOutput](docs/AuthenticationSmsOutput.md)
 - [YousignClient::Body](docs/Body.md)
 - [YousignClient::Body1](docs/Body1.md)
 - [YousignClient::Body2](docs/Body2.md)
 - [YousignClient::CheckDocumentBankAccountsInput](docs/CheckDocumentBankAccountsInput.md)
 - [YousignClient::CheckDocumentBankAccountsOutput](docs/CheckDocumentBankAccountsOutput.md)
 - [YousignClient::CheckDocumentIdentitiesInput](docs/CheckDocumentIdentitiesInput.md)
 - [YousignClient::CheckDocumentIdentitiesOutput](docs/CheckDocumentIdentitiesOutput.md)
 - [YousignClient::ConfigEmailTemplate](docs/ConfigEmailTemplate.md)
 - [YousignClient::ConfigWebhookTemplate](docs/ConfigWebhookTemplate.md)
 - [YousignClient::ConsentProcessInput](docs/ConsentProcessInput.md)
 - [YousignClient::ConsentProcessOutput](docs/ConsentProcessOutput.md)
 - [YousignClient::ConsentProcessValueInput](docs/ConsentProcessValueInput.md)
 - [YousignClient::ConsentProcessValueOutput](docs/ConsentProcessValueOutput.md)
 - [YousignClient::FileInput](docs/FileInput.md)
 - [YousignClient::FileInputMetadata](docs/FileInputMetadata.md)
 - [YousignClient::FileObjectInput](docs/FileObjectInput.md)
 - [YousignClient::FileObjectInputWithoutFileReference](docs/FileObjectInputWithoutFileReference.md)
 - [YousignClient::FileObjectOutput](docs/FileObjectOutput.md)
 - [YousignClient::FileObjectOutputWithoutFileReference](docs/FileObjectOutputWithoutFileReference.md)
 - [YousignClient::FileOutput](docs/FileOutput.md)
 - [YousignClient::InlineResponse400](docs/InlineResponse400.md)
 - [YousignClient::InweboUserRequest](docs/InweboUserRequest.md)
 - [YousignClient::MemberInput](docs/MemberInput.md)
 - [YousignClient::MemberOutput](docs/MemberOutput.md)
 - [YousignClient::ModeSmsConfiguration](docs/ModeSmsConfiguration.md)
 - [YousignClient::OperationInput](docs/OperationInput.md)
 - [YousignClient::OperationOutput](docs/OperationOutput.md)
 - [YousignClient::OperationOutputMetadata](docs/OperationOutputMetadata.md)
 - [YousignClient::OrganizationBillingAddress](docs/OrganizationBillingAddress.md)
 - [YousignClient::OrganizationOutput](docs/OrganizationOutput.md)
 - [YousignClient::ProcedureConfig](docs/ProcedureConfig.md)
 - [YousignClient::ProcedureConfigEmail](docs/ProcedureConfigEmail.md)
 - [YousignClient::ProcedureConfigReminder](docs/ProcedureConfigReminder.md)
 - [YousignClient::ProcedureConfigReminderConfig](docs/ProcedureConfigReminderConfig.md)
 - [YousignClient::ProcedureConfigReminderConfigEmail](docs/ProcedureConfigReminderConfigEmail.md)
 - [YousignClient::ProcedureConfigWebhook](docs/ProcedureConfigWebhook.md)
 - [YousignClient::ProcedureDuplicateInput](docs/ProcedureDuplicateInput.md)
 - [YousignClient::ProcedureInput](docs/ProcedureInput.md)
 - [YousignClient::ProcedureInputMetadata](docs/ProcedureInputMetadata.md)
 - [YousignClient::ProcedureOutput](docs/ProcedureOutput.md)
 - [YousignClient::ProcedureOutputMetadata](docs/ProcedureOutputMetadata.md)
 - [YousignClient::ProcedureRemindConfig](docs/ProcedureRemindConfig.md)
 - [YousignClient::ProcedureRemindConfigEmail](docs/ProcedureRemindConfigEmail.md)
 - [YousignClient::ProcedureRemindInput](docs/ProcedureRemindInput.md)
 - [YousignClient::ServerStampConfig](docs/ServerStampConfig.md)
 - [YousignClient::ServerStampConfigWebhook](docs/ServerStampConfigWebhook.md)
 - [YousignClient::ServerStampInput](docs/ServerStampInput.md)
 - [YousignClient::ServerStampOutput](docs/ServerStampOutput.md)
 - [YousignClient::SignatureUiInput](docs/SignatureUiInput.md)
 - [YousignClient::SignatureUiInputRedirectCancel](docs/SignatureUiInputRedirectCancel.md)
 - [YousignClient::SignatureUiInputRedirectError](docs/SignatureUiInputRedirectError.md)
 - [YousignClient::SignatureUiInputRedirectSuccess](docs/SignatureUiInputRedirectSuccess.md)
 - [YousignClient::SignatureUiInputUpdate](docs/SignatureUiInputUpdate.md)
 - [YousignClient::SignatureUiLabelInput](docs/SignatureUiLabelInput.md)
 - [YousignClient::SignatureUiLabelInputIncluded](docs/SignatureUiLabelInputIncluded.md)
 - [YousignClient::SignatureUiLabelOutput](docs/SignatureUiLabelOutput.md)
 - [YousignClient::SignatureUiOutput](docs/SignatureUiOutput.md)
 - [YousignClient::SignatureUiOutputRedirectCancel](docs/SignatureUiOutputRedirectCancel.md)
 - [YousignClient::SignatureUiOutputRedirectError](docs/SignatureUiOutputRedirectError.md)
 - [YousignClient::SignatureUiOutputRedirectSuccess](docs/SignatureUiOutputRedirectSuccess.md)
 - [YousignClient::UserGroup](docs/UserGroup.md)
 - [YousignClient::UserInput](docs/UserInput.md)
 - [YousignClient::UserInputNotifications](docs/UserInputNotifications.md)
 - [YousignClient::UserOutput](docs/UserOutput.md)
 - [YousignClient::UserOutputNotifications](docs/UserOutputNotifications.md)
 - [YousignClient::UserWorkspaceOutput](docs/UserWorkspaceOutput.md)
 - [YousignClient::WorkspaceConfig](docs/WorkspaceConfig.md)
 - [YousignClient::WorkspaceConfigEmail](docs/WorkspaceConfigEmail.md)
 - [YousignClient::WorkspaceConfigProcedure](docs/WorkspaceConfigProcedure.md)
 - [YousignClient::WorkspaceOutput](docs/WorkspaceOutput.md)


## Documentation for Authorization


### api_key

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

